Articles - a php blogging engine (v.1.2 2024-02-18)
===================================================


Description
===========

Articles is a tiny blogging engine written in php.
The aim was to create the least complicated blogging engine which still offered core funcitonality. Highly customizable. For those who know a little html, css, php at least. And perhaps js.
It meant to be a reply to the challange (of mine): how a blogging engine can work, if only html files - the blog entries themselves - are used to store all the necessary data, without any type of database (be it db management system, or JSON files, or any other).


Changelog
=========

2.0
- reworked the whole code base, it's "object oriented" now, uses the Article class to create each blog and catalog entry
- changed the generate catalog function, merged the two (regular and tag view) into one
- for individual blog pages added new meta tags to the page head to make it more shareable, social media friendly

1.2
- made styling (CSS) class-based, instead of directly selecting elements in order to make customization easier
- fixed href in the link within h1 element in header.html

1.1
- reworked GET sanitization and validation
- changed extraction of timestamps from filenames
- deleted extractDate function
- added prepareTag function


Prerequisites
=============

A webserver. The application was written with a GNU/Linux system with Apache2/Nginx/etc. in mind.


Files and Directories
=====================

README.md
    This file you are reading now.

config.php
    Containes configuration options, variable and function definitions.

carticle.sh
    Convenience tool. A blog entry template generator for bash. Creates a very simple html file with couple of markups to alleviate the need to go through the same steps of entry generation. Appropriate file naming too.
    
public/
    The document root for your web blog.

public/content/articles/
    The directory for the blog entries. After you wrote one, upload it to here.
public/content/articles/1708168043.html
    An example file how a blog entry should look like.
public/content/media/
    The directory for the media that you link/embed into blog entries.

public/html/
    HTML files containing snippets, templates of the website. If you want to add to the structure of the site, edit these.
public/html/footer.html
    The footer displayed on each page of the blog. If you want to add something to the footer, edit this file.
public/html/header.html
    The header displayed on each page of the blog. If you want to add something to the header, edit this file.

public/img/
    Images that are part of the structure of your website - not part of the content of the blog entries - such as icons, backgrounds, cursors, favicon, etc. go here.

public/scripts/
    Store JavaScript files here.
public/scripts/blog.js
    A dummy JavaScript file, that serves no particular purpose beside being a placeholder. The blog needs no JS to be usable. If you want scripts running, edit this file, or ignore/delete it and write your own.

public/styles/
    Store CSS here.
public/styles/blog.css
    Contains a very basic CSS ruleset to give the blog digestable look out of the box. If you wish to add your own rules, I suggest creating a new file, which complements this one. Or just edit this whatever.

blog.php
    Serves the indivdual blog entries.
catalog.php
    Serves the catalog - sorted by year or by specific tags.
index.php
    The main page, the core of the blog.


Installation
============

Extract anywhere then upload files and folders into the document root of the webserver, with the exception of "carticle.sh" and "example.html".
    Example: /var/www/myblog.com/
Set document root to the public folder:
    /var/www/myblog.com/public
In the above example the index.php will be found at:
    /var/www/myblog.com/public/index.php
Do the necessary steps to publish the new website.


Usage
=====

1. Open your favourite text editor and write a blogpost, Use HTML markup.
2. Upload the file to the "public/content/articles/" directory, if you included media within your post upload those "public/content/media/"


Rules for creating and editing a post
-------------------------------------

- Filenames must be Unix timestamps followed by ".html". Example: "1708168043.html"
- Use all html elements true, where closing tags needed add those.
- Do not create complete html files as your blog post, like you would for a static site. It would result in failure. You only need to create the contents of an article.
- Start each file with a "<h3>" element, with the title of your post. Example: "<h3>Very first blog post</h3>"
- Include the title within the h3 element.
- Do not use any of these elements within your blogposts: !DOCTYPE, html, head, body, header, footer, article.
- Use the rest of html elements logically, sensibly. "<p></p>" for paragraphs, "<img>" for images, "<ul></ul>" for unordered lists, etc.
- When you incorporate a media to your post, the source (src attribute) should point to "public/content/media/" and upload the files to that directory.


Use of carticle.sh
------------------

This is a bash script to make post creation simple. You run it as you'd run any bash scripts.
What it does:
- generates an Unix timestamp of the exact time you run the command;
- creates a file and names it with the timestamp, and adds a .html extension to it;
- appends a line containing a "<h3></h3>" element;
- appends a line containing a "<p></p>" element.
The result will be the bare minimum for a blog post.
You can open this file with your fav text editor or IDE or anything you use to complete your brand new post for your blog.


Tag system
----------

To utilize the tag system you have to add the tags at the end of the blog post. For that use a custom html: "<e-tag></e-tag>" with each tag you want to add, have to start each on a new line.
Examples:
<e-tag>dev</e-tag>
<e-tag>humor</e-tag>
<e-tag>books</e-tag>
<e-tag>journal</e-tag>
<e-tag>php</e-tag>


Suggestions, pro-tips
---------------------

Upload the blog posts with scp or rsync.
Have a directory on your local machine with all the files of this blogging engine, and store your articles in the "content/articles/" directory, and use rsync to upload your files. This way you can modify earlier posts, or the css or change the config, or anything else locally, and you can sync your folders on the server.
For utilising the "carticle.sh" script I suggest having a ".local/bin/" directory in your home folder, added to the $PATH.


Authors
=======
Wloff Apps, Services, Development


License
=======
Articles is licensed under GPL 3.0
See: lincense.txt
Or: https://www.gnu.org/licenses/gpl-3.0.en.html
